<?php
/*
Plugin Name: BetterWPReadMore
Plugin URI: http://nslog.com/plugins/betterwpreadmore/
Description: Cleans up WordPress "read more" links
Version: 0.2
Author: Erik J. Barzeski
Author URI: http://nslog.com/
*/

/* 
ChangeLog
0.1		* Initial release
0.2		* Updated to work with WordPress 2.1
*/



# include admin stuff when relevant
if ( strpos($_SERVER['REQUEST_URI'], 'wp-admin') !== false )
{
	include_once dirname(__FILE__) . '/BetterWPReadMore_Admin.php';
}

function nslog_readmore_init()
{
	$defaults = array(
		'remove_idlink' => true,
		'remove_anchor' => true,
		'add_title' => true,
		'new_paragraph' => true
	);

	$options = get_option('nslog_readmore_options');
	
	$initialize = false;

	foreach ( $defaults as $key => $val )
	{
		if ( !isset($options[$key]) )
		{
			$options[$key] = $val;
			$initialize = true;
		}
	}

	if ( $initialize )
	{
		update_option('nslog_readmore_options', $options);
	}
} // end of nslog_readmore_init

add_action('init', 'nslog_readmore_init');



function nslog_betterwpreadmore($nslog_content)
{
	global $post;
	$id = $post->ID;
	
	$options = get_option('nslog_readmore_options');
	// 'remove_idlink', 'remove_anchor', 'add_title', 'new_paragraph'
	//    a id=""        #more-xxxx       title        p vs. span
	
	$morelink = '';
	$this_permalink = get_permalink();

	// Adds and removes line breaks and <a id=""> from individual pages
	// This helps in formatting regardless of the other options.
	$moreid = '<a id="more-' . $id . '"></a>';
	$nslog_content = str_replace("\n".$moreid, $moreid, $nslog_content);
	$nslog_content = str_replace($moreid, $moreid."\n", $nslog_content);

	// Removes # from "read more" links on index
	if($options['remove_idlink'])
	{
		// Removes the <a id="more-xxxx"></a> from the content
		$nslog_content = str_replace($moreid, '', $nslog_content);
	}

	// Removes cruft found in WP 2.1
	$nslog_content = str_replace(' class="more-link"', '', $nslog_content);

	// Remove the carriage return before the read more link
	$replace_space = '<a href="'.$this_permalink.'#more-'. $id .'">';
	$nslog_content = str_replace("\n ".$replace_space, $replace_space, $nslog_content);


	$morelink = ($options['remove_anchor']) ?
					'<a href="'.$this_permalink.'"' :
					'<a href="'.$this_permalink.'#more-'. $id .'"';
	
	// Add the title to the link if it's there
	if($options['add_title'])
	{
		$morelink .= ' title="'.the_title('', '', false).'"';
	}


	// match the read more link
	$match_str = '{<a href=(.*?)#more-'. $id .'">(.+?)</a>}s';
//	$match_str = '{<a href='.$this_permalink.'#more-'. $id .'">(.+?)</a>}s';

	$is_more_to_read = preg_match("$match_str", $nslog_content, $matches);
	$read_more_text = end($matches);

	$morelink .= '>' . $read_more_text . '</a>';
	$origlink = '<a href="'.$this_permalink.'#more-'. $id . '">' . $read_more_text . '</a>';
	
	if($options['new_paragraph'])
	{
		$morelink = '</p><p class="readmorelink">' . $morelink;
	}
	else
	{
		$morelink = ' <span class="readmorelink">' . $morelink . '</span>';
	}
	
	$nslog_content = str_replace($origlink, $morelink, $nslog_content);

	return $nslog_content;
}



add_filter('the_content', 'nslog_betterwpreadmore', 7);

?>